@@ -1,6 +1,7 @@
 # Imports used through the rest of the notebook.
 import hashlib
 from datetime import datetime
+from typing import Text
 
 import torchaudio
 
@@ -9,17 +10,20 @@ from ruth_tts_transformer.ruth_tts.utils.audio import load_voice
 
 
 class TTS:
-    def __init__(self):
+    def __init__(self, voice: Text = "gabby_reading"):
         self.gen = None
         self.preset = "ultra_fast"
-        self.voice = "hendry"
+        self.voice = voice
         self.tts = TextToSpeech()
 
     def generate(self, text):
         voice_samples, conditioning_latents = load_voice(self.voice)
-        gen = self.tts.tts_with_preset(text, voice_samples=voice_samples, conditioning_latents=conditioning_latents,
-                                       preset=self.preset)
-        self.gen = gen
+        self.gen, _ = self.tts.tts(text, voice_samples=voice_samples,
+                                   conditioning_latents=conditioning_latents,
+                                   use_deterministic_seed=0,
+                                   return_deterministic_state=True,
+                                   num_autoregressive_samples=16,
+                                   diffusion_iterations=30)
 
     def parse(self):
         file_name = hashlib.sha1(str(datetime.now()).encode("UTF-8"))
